@@ -14,15 +14,23 @@ func (e *Engine) killCmd(cmd *exec.Cmd) (pid int, err error) {
 	if e.config.Build.SendInterrupt {
 		// Sending a signal to make it clear to the process that it is time to turn off
 		if err = syscall.Kill(-pid, syscall.SIGINT); err != nil {
+			e.mainDebug("trying to send signal failed %v", err)
 			return
 		}
 		time.Sleep(e.config.Build.KillDelay * time.Millisecond)
 	}
-	// https://stackoverflow.com/questions/22470193/why-wont-go-kill-a-child-process-correctly
-	err = syscall.Kill(-pid, syscall.SIGKILL)
+	err = killByPid(pid)
+	if err != nil {
+		return pid, err
+	}
 	// Wait releases any resources associated with the Process.
-	_, _ = cmd.Process.Wait()
-	return pid, err
+	_, err = cmd.Process.Wait()
+	if err != nil {
+		return pid, err
+	}
+
+	e.mainDebug("killed process pid %d successed", pid)
+	return pid, nil
 }
 
 func (e *Engine) startCmd(cmd string) (*exec.Cmd, io.WriteCloser, io.ReadCloser, io.ReadCloser, error) {
