@@ -2,11 +2,10 @@ package runner
 
 import (
 	"io"
+	"os"
 	"os/exec"
 	"syscall"
 	"time"
-
-	"github.com/creack/pty"
 )
 
 func (e *Engine) killCmd(cmd *exec.Cmd) (pid int, err error) {
@@ -28,8 +27,27 @@ func (e *Engine) killCmd(cmd *exec.Cmd) (pid int, err error) {
 	return
 }
 
-func (e *Engine) startCmd(cmd string) (*exec.Cmd, io.ReadCloser, io.ReadCloser, error) {
+func (e *Engine) startCmd(cmd string) (*exec.Cmd, io.WriteCloser, io.ReadCloser, io.ReadCloser, error) {
 	c := exec.Command("/bin/sh", "-c", cmd)
-	f, err := pty.Start(c)
-	return c, f, f, err
+	stderr, err := c.StderrPipe()
+	if err != nil {
+		return nil, nil, nil, nil, err
+	}
+	stdout, err := c.StdoutPipe()
+	if err != nil {
+		return nil, nil, nil, nil, err
+	}
+	stdin, err := c.StdinPipe()
+	if err != nil {
+		return nil, nil, nil, nil, err
+	}
+	c.Stdout = os.Stdout
+	c.Stderr = os.Stderr
+	c.Stdin = os.Stdin
+
+	err = c.Start()
+	if err != nil {
+		return nil, nil, nil, nil, err
+	}
+	return c, stdin, stdout, stderr, nil
 }
